"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const WebpackWindiCSSPlugin = require("windicss-webpack-plugin");
const constant_1 = require("./constant");
const fs = require("fs-extra");
const path = require("path");
const getConfigPath = (platform) => `${constant_1.HIDDEN_CONFIG_PATH}/${platform}.config.js`;
const checkConfigExists = (platform) => fs.existsSync(path.resolve(getConfigPath(platform)));
exports.default = (ctx, config) => {
    const requiredConfigFileExists = ["h5", "mini"].some((platform) => checkConfigExists(platform));
    ctx.onBuildStart(() => {
        if (!requiredConfigFileExists) {
            console.log(ctx.helper.chalk.yellowBright(`⚠️ [taro-plugin-tailwind]: required config (h5.config.js / mini.config.js) is missing, auto skipping...`));
            return;
        }
        if (!constant_1.SUPPORTED_PLATFORMS.includes(constant_1.CURRENT_PLATFORM)) {
            console.log(ctx.helper.chalk.yellowBright(`⚠️ [taro-plugin-tailwind]: platform ${constant_1.CURRENT_PLATFORM} is not supported, auto skipping...`));
            return;
        }
    });
    ctx.modifyWebpackChain(({ chain }) => {
        let configFilePath = `${constant_1.HIDDEN_CONFIG_PATH}/${constant_1.CURRENT_PLATFORM}.config.js`;
        if (!fs.existsSync(path.resolve(configFilePath))) {
            console.log(ctx.helper.chalk.yellowBright(`⚠️ [taro-plugin-tailwind]: auto fallback to mini.config.js...`));
            configFilePath = `${constant_1.HIDDEN_CONFIG_PATH}/mini.config.js`; // fallback
        }
        // copy tailwind.config.js to root directory for tailwind intellisense support
        if (!fs.existsSync(path.resolve("tailwind.config.js"))) {
            fs.copySync(path.resolve(configFilePath), "tailwind.config.js");
            console.log(ctx.helper.chalk.greenBright(`⚠️ [taro-plugin-tailwind]: copied ${configFilePath} as tailwind.config.js to root directory...`));
        }
        chain.plugin("windicss-webpack-plugin").use(WebpackWindiCSSPlugin, [
            Object.assign({ scan: {
                    dirs: ["./src"],
                    fileExtensions: ["vue", "jsx", "tsx"],
                }, config: path.resolve("./tailwind.config.js") }, config),
        ]);
        if (constant_1.SUPPORTED_MINI_PLATFORMS.includes(constant_1.CURRENT_PLATFORM)) {
            chain.merge({
                module: {
                    rule: {
                        taroTailwindLoader: {
                            test: "windi.css",
                            use: [
                                {
                                    loader: "postcss-loader",
                                    options: {
                                        postcssOptions: {
                                            plugins: [
                                                [
                                                    "postcss-selector-replace",
                                                    {
                                                        before: ["*"],
                                                        after: [":root"],
                                                    },
                                                ],
                                            ],
                                        },
                                    },
                                },
                            ],
                        },
                    },
                },
            });
        }
    });
};
//# sourceMappingURL=chain.js.map